import { DUMMY_OBJECT } from '../constants';
import { mergeObjects, emptyObject, updateObjectValueByKey, removeObjectByKeys, removeObjectByKey } from '../objectCRUD'; // filepath: /Users/mari-19987/React_Package_02/jsapps/dot/dotkit/src/utils/objectCRUD.test.js

describe('mergeObjects', () => {
  test('merges two objects with no overlapping keys', () => {
    const object = {
      a: 1,
      b: 2
    };
    const newObject = {
      c: 3,
      d: 4
    };
    const result = mergeObjects({
      object,
      newObject
    });
    expect(result).toEqual({
      a: 1,
      b: 2,
      c: 3,
      d: 4
    });
  });
  test('merges two objects with overlapping keys (new object overwrites)', () => {
    const object = {
      a: 1,
      b: 2
    };
    const newObject = {
      b: 3,
      c: 4
    };
    const result = mergeObjects({
      object,
      newObject
    });
    expect(result).toEqual({
      a: 1,
      b: 3,
      c: 4
    });
  });
  test('merges an empty object with another object', () => {
    const object = DUMMY_OBJECT;
    const newObject = {
      a: 1,
      b: 2
    };
    const result = mergeObjects({
      object,
      newObject
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
  test('merges an object with undefined or null values', () => {
    const object = {
      a: 1,
      b: 2
    };
    const newObject = {
      b: null,
      c: undefined
    };
    const result = mergeObjects({
      object,
      newObject
    });
    expect(result).toEqual({
      a: 1,
      b: null,
      c: undefined
    });
  });
  test('merges objects with nested structures', () => {
    const object = {
      a: 1,
      b: {
        x: 10,
        y: 20
      }
    };
    const newObject = {
      b: {
        z: 30
      },
      c: 3
    };
    const result = mergeObjects({
      object,
      newObject
    });
    expect(result).toEqual({
      a: 1,
      b: {
        z: 30
      },
      c: 3
    });
  });
});
describe('emptyObject', () => {
  test('returns the DUMMY_OBJECT constant', () => {
    const result = emptyObject();
    expect(result).toEqual(DUMMY_OBJECT);
  });
});
describe('updateObjectValueByKey', () => {
  test('updates a specific key with a new value', () => {
    const object = {
      a: 1,
      b: 2
    };
    const result = updateObjectValueByKey({
      object,
      key: 'b',
      value: 3
    });
    expect(result).toEqual({
      a: 1,
      b: 3
    });
  });
  test('adds a new key if it does not exist', () => {
    const object = {
      a: 1
    };
    const result = updateObjectValueByKey({
      object,
      key: 'b',
      value: 2
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
});
describe('removeObjectByKeys', () => {
  test('removes specified keys from the object', () => {
    const object = {
      a: 1,
      b: 2,
      c: 3
    };
    const result = removeObjectByKeys({
      object,
      keys: ['b', 'c']
    });
    expect(result).toEqual({
      a: 1
    });
  });
  test('does nothing if keys array is empty', () => {
    const object = {
      a: 1,
      b: 2
    };
    const result = removeObjectByKeys({
      object,
      keys: []
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
  test('does nothing if keys do not exist in the object', () => {
    const object = {
      a: 1,
      b: 2
    };
    const result = removeObjectByKeys({
      object,
      keys: ['c', 'd']
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
});
describe('removeObjectByKey', () => {
  test('removes a specific key from the object', () => {
    const object = {
      a: 1,
      b: 2
    };
    const result = removeObjectByKey({
      object,
      key: 'b'
    });
    expect(result).toEqual({
      a: 1
    });
  });
  test('does nothing if the key does not exist', () => {
    const object = {
      a: 1,
      b: 2
    };
    const result = removeObjectByKey({
      object,
      key: 'c'
    });
    expect(result).toEqual({
      a: 1,
      b: 2
    });
  });
});